# -*- coding: utf-8 -*-
"""
Attributes:
  SPACY_PKG (dict): key is language abbreviation, and value is spacy package name
"""

SPACY_PKG = {
  "en": "en_core_web_trf",
  "es": "es_dep_news_trf",
}
